@@ -1,40 +1,11 @@
 package Treex::Block::Read::CoNLLX;
-BEGIN {
-  $Treex::Block::Read::CoNLLX::VERSION = '0.08170';
-}
+$Treex::Block::Read::CoNLLX::VERSION = '0.13095';
+use strict;
+use warnings;
 use Moose;
 use Treex::Core::Common;
 use File::Slurp;
-extends 'Treex::Block::Read::BaseTextReader';
-
-sub next_document_text {
-    my ($self) = @_;
-    my $FH = $self->_current_fh;
-    if ( !$FH ) {
-        $FH = $self->next_filehandle() or return;
-        $self->_set_current_fh($FH);
-    }
-
-    if ( $self->is_one_doc_per_file ) {
-        $self->_set_current_fh(undef);
-        return read_file($FH);
-    }
-
-    my $text;
-    my $empty_lines;
-
-    LINE:
-
-    while (<$FH>) {
-        if ( $_ =~ m/^\s*$/ ) {
-            $empty_lines++;
-            return $text if $empty_lines == $self->lines_per_doc;
-        }
-        $text .= $_;
-    }
-
-    return $text;
-}
+extends 'Treex::Block::Read::BaseCoNLLReader';
 
 sub next_document {
     my ($self) = @_;
@@ -89,7 +60,7 @@ Treex::Block::Read::CoNLLX
 
 =head1 VERSION
 
-version 0.08170
+version 0.13095
 
 =head1 DESCRIPTION
 
@@ -136,6 +107,6 @@ David Mareček
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011-2013 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
